@@ -1,9 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "hyperbole" "9.0.1"
+(define-package "hyperbole" "20251018.1734"
   "GNU Hyperbole: The Everyday Hypertextual Information Manager."
-  '((emacs "27.1"))
+  '((emacs "28"))
   :url "http://www.gnu.org/software/hyperbole"
-  :commit "b36debbea873c2360a6782abcce084f78c0c9ff2"
-  :revdesc "b36debbea873"
+  :commit "a9ccfa94b6724b614d4c019172b6a694003c7e8f"
+  :revdesc "a9ccfa94b672"
   :keywords '("comm" "convenience" "files" "frames" "hypermedia" "languages" "mail" "matching" "mouse" "multimedia" "outlines" "tools" "wp")
-  :maintainers '(("Mats Lidell" . "matsl@gnu.org")))
+  :authors '(("Robert Weiner" . "rsw@gnu.org"))
+  :maintainers '(("Robert Weiner" . "rsw@gnu.org")))
