@@ -2,19 +2,20 @@
 
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 ;;
-;; Copyright (C) 1992-2024  Free Software Foundation, Inc.
+;; Copyright (C) 1992-2025  Free Software Foundation, Inc.
 
-;; Authors:      Robert Weiner <rsw@gnu.org>
-;; Maintainer:   Mats Lidell <matsl@gnu.org>
+;; Author:       Robert Weiner <rsw@gnu.org>
+;; Authors:      Robert Weiner <rsw@gnu.org>, Mats Lidell <matsl@gnu.org>
+;; Maintainer:   Robert Weiner <rsw@gnu.org>
 ;; Maintainers:  Robert Weiner <rsw@gnu.org>, Mats Lidell <matsl@gnu.org>
 ;; Created:      06-Oct-92 at 11:52:51
-;; Last-Mod:     10-Mar-24 at 12:50:16 by Bob Weiner
+;; Last-Mod:      2-Oct-25 at 14:28:52 by Mats Lidell
 ;; Released:     10-Mar-24
-;; Package-Version: 9.0.1
-;; Package-Revision: b36debbea873
+;; Package-Version: 20251018.1734
+;; Package-Revision: a9ccfa94b672
 ;; Keywords:     comm, convenience, files, frames, hypermedia, languages, mail, matching, mouse, multimedia, outlines, tools, wp
 ;; Package:      hyperbole
-;; Package-Requires: ((emacs "27.1"))
+;; Package-Requires: ((emacs "28"))
 ;; URL:          http://www.gnu.org/software/hyperbole
 
 ;; See the "HY-COPY" file for license information.
@@ -83,9 +84,6 @@
 (defconst hyperbole-loading t
   "Temporary constant available for testing while Hyperbole is loading.")
 
-;; Ensure defgroup and defcustom are defined for use throughout Hyperbole.
-(require 'custom)
-
 (defgroup hyperbole nil
   "Hyperbole customizations category."
   :group 'applications)
@@ -141,7 +139,7 @@ Use nil for no Hyperbole mode indicator."
 
 ;;;###autoload
 (define-minor-mode hyperbole-mode
-  "Toggle Hyperbole global minor mode.
+  "Toggle Hyperbole global minor mode with \\[hyperbole-mode].
 
 Hyperbole is the Everyday Hypertextual Information Manager.
 
@@ -158,9 +156,6 @@ Info documentation at \"(hyperbole)Top\".
       (hyperbole--enable-mode)
     (hyperbole--disable-mode)))
 
-(defvar hyperbole--mark-even-if-inactive
-  "Stores value of `mark-even-if-inactive' prior to enabling `hyperbole-mode'.")
-
 ;;; ************************************************************************
 ;;; Public declarations
 ;;; ************************************************************************
@@ -309,13 +304,21 @@ of the commands."
     ;; of unit selected each time.
     (hkey-maybe-set-key "\C-c\C-m" #'hui-select-thing)
     ;;
-    ;; Override the {M-w} command from "simple.el" when hyperbole-mode is active
-    ;; to allow copying delimited things, kcell references or regions to the kill ring.
-    (hkey-set-key [remap kill-ring-save] #'hui-kill-ring-save)
+    ;; Override the {C-w} command from either "completion.el" or
+    ;; "simple.el" when hyperbole-mode is active to allow killing
+    ;; kcell references, active regions and delimited areas (like
+    ;; sexpressions).
+    (hkey-set-key [remap completion-kill-region] #'hui:kill-region)
+    (hkey-set-key [remap kill-region]            #'hui:kill-region)
+    ;;
+    ;; Override the {M-w} command from "simple.el" when hyperbole-mode
+    ;; is active to allow copying delimited things, kcell references
+    ;; or regions to the kill ring.
+    (hkey-set-key [remap kill-ring-save]         #'hui:kill-ring-save)
     ;;
     ;; Override the {C-x r s} command from "register.el" when hyperbole-mode is active
     ;; to allow copying delimited things, kcell references or regions to a register.
-    (hkey-set-key "\C-xrs" #'hui-copy-to-register)
+    (hkey-set-key "\C-xrs" #'hui:copy-to-register)
     ;;
     ;; Bind {C-c @} to create a user-specified sized grid of windows
     ;; displaying different buffers.
@@ -471,7 +474,8 @@ frame, those functions by default still return the prior frame."
 		   user-mail-address)
 	      (concat (user-login-name) (hypb:domain-name)))))
   ;;
-  ;; Modify syntactic character pairs for use with implicit button activations.
+  ;; Modify syntactic character pairs for use with implicit button activations
+  ;; in text and help modes.
   (hbut:modify-syntax)
   ;;
   ;; Conditionally initialize Hyperbole key bindings (when hkey-init is t).
@@ -486,9 +490,11 @@ frame, those functions by default still return the prior frame."
   ;; initialized, if not yet set by the user.
   (when (eq hsys-org-enable-smart-keys 'unset)
     (customize-set-variable 'hsys-org-enable-smart-keys
-			    (if (hsys-org-meta-return-shared-p)
-				'buttons
-			      t)))
+			    (cond ((car-safe (get 'hsys-org-enable-smart-keys 'customized-value)))
+				  ((car-safe (get 'hsys-org-enable-smart-keys 'saved-value)))
+				  ((hsys-org-meta-return-shared-p)
+				   :buttons)
+				  (t))))
   ;;
   ;; This next function call must be run before any tests involving Org
   ;; in case the user has installed a new version of Org but Emacs has
@@ -508,8 +514,8 @@ frame, those functions by default still return the prior frame."
   (message "Initializing Hyperbole...done"))
   
 
-  ;; This call loads the rest of the Hyperbole system.
-  (require 'hinit)
+;; This call loads the rest of the Hyperbole system.
+(require 'hinit)
 
 (defun hyperbole--enable-mode ()
   "Enable Hyperbole global minor mode."
@@ -519,6 +525,11 @@ frame, those functions by default still return the prior frame."
     (hyperb:init)
     (remove-hook 'after-init-hook #'hyperb:init))
   ;;
+  ;; Update mode-line hover doc in blank areas for button-2 and
+  ;; button-3 if using unshifted Smart Keys.
+  (set-variable mode-line-default-help-echo #'hmouse-modeline-default-help-echo)
+  (force-mode-line-update t)
+  ;;
   ;; Abbreviate MSWindows /cygdrive mount point paths.
   (when (file-exists-p "/cygdrive")
     (add-to-list 'directory-abbrev-alist hyperb:cygdrive))
@@ -537,6 +548,8 @@ frame, those functions by default still return the prior frame."
 
 (defun hyperbole--disable-mode ()
   "Disable Hyperbole keys, menus and hooks."
+  ;; Deactivate hywiki-mode
+  (hywiki-mode 0)
   ;; Deactivate hyperbole-mode
   ;; Delete Hyperbole menu from all menubars.
   (hui-menu-remove Hyperbole)
